@@ -34,10 +34,10 @@ class LogTests(TestCase):
         # except Exception as e:
         #     logger.error('test error: %s', e)
         #     logger.fatal('test fatal: %s', e)
-        count = 0
-        for i in range(10000):
-            logger.warning('test warn')
-            count += 1
-        print("已发送日志: {}条".format(count))
+        # count = 0
+        # for i in range(10000):
+        #     logger.warning('test warn')
+        #     count += 1
+        # print("已发送日志: {}条".format(count))
 
         sleep(30)
